@@ -1,3 +1,5 @@
+from typing import Union, Callable
+
 from django.db import models
 
 
@@ -7,7 +9,7 @@ class DBView(models.Model):
             view_definition - define the view, can be callable or attribute (string)
             view definition can be per db engine.
     """
-    pass
+    view_definition: Union[Callable, str, dict]
 
     class Meta:
         abstract = True
