@@ -2,6 +2,7 @@ import sys
 
 from django.apps import apps
 from django.db.migrations.loader import MigrationLoader
+from django.db.migrations.questioner import MigrationQuestioner, InteractiveMigrationQuestioner
 from django.db.migrations.state import ProjectState
 from django.core.management.commands.makemigrations import Command as MakemigrationsCommand
 
@@ -67,6 +68,7 @@ class Command(MakemigrationsCommand):
         autodetector = ViewMigrationAutoDetector(
             from_state,
             to_state,
+            questioner=InteractiveMigrationQuestioner(specified_apps=app_labels, dry_run=self.dry_run)
         )
 
         changes = autodetector.changes(
